oc\_ocdm.graph.entities.bibliographic.discourse\_element module
---------------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.discourse_element
   :members:
   :undoc-members:
   :show-inheritance:
